@@ -1,18 +1,3 @@
-=encoding UTF-8
-
-=head1 NAME
-
-Image::Quantize - abstract here.
-
-=head1 SYNOPSIS
-
-    use Image::Quantize;
-
-=head1 DESCRIPTION
-
-=head1 FUNCTIONS
-
-=cut
 package Image::Quantize;
 require Exporter;
 @ISA = qw(Exporter);
@@ -23,7 +8,7 @@ require Exporter;
 use warnings;
 use strict;
 use Carp;
-our $VERSION = '0.00_02';
+our $VERSION = '0.00_03';
 require XSLoader;
 XSLoader::load ('Image::Quantize', $VERSION);
 
