@@ -641,6 +641,22 @@ LIQ_EXPORT liq_result *liq_quantize_image(liq_attr *attr, liq_image *img)
     return result;
 }
 
+LIQ_EXPORT liq_error liq_quantize_image_2(liq_attr *attr, liq_image *img,
+					  liq_result ** result_ptr)
+{
+    if (!CHECK_STRUCT_TYPE(attr, liq_attr)) return LIQ_INVALID_POINTER;
+    if (!CHECK_STRUCT_TYPE(img, liq_image)) return LIQ_INVALID_POINTER;
+
+    histogram *hist = get_histogram(img, attr);
+    if (!hist) return LIQ_HISTOGRAM_FAILED;
+
+    liq_result *result = pngquant_quantize(hist, attr, img->gamma);
+    * result_ptr = result;
+
+    pam_freeacolorhist(hist);
+    return LIQ_OK;
+}
+
 LIQ_EXPORT liq_error liq_set_dithering_level(liq_result *res, float dither_level)
 {
     if (!CHECK_STRUCT_TYPE(res, liq_result)) return LIQ_INVALID_POINTER;
